@@ -54,9 +54,9 @@ public:
 private:
     void processPart(KMime::Content *content, KMime::Content *mainContent);
     void process(const KMime::Message::Ptr &msg);
-    Xapian::WritableDatabase *m_db;
-    Xapian::Document *m_doc;
-    Xapian::TermGenerator *m_termGen;
+    Xapian::WritableDatabase *m_db = nullptr;
+    Xapian::Document *m_doc = nullptr;
+    Xapian::TermGenerator *m_termGen = nullptr;
 };
 
 #endif // AKONOTESINDEXER_H
