@@ -29,17 +29,17 @@
 #include <KEmailAddress>
 
 EmailIndexer::EmailIndexer(const QString &path, const QString &contactDbPath):
-    AbstractIndexer(), m_doc(0), m_termGen(0), m_contactDb(0)
+    AbstractIndexer(), m_doc(nullptr), m_termGen(nullptr), m_contactDb(nullptr)
 {
     try {
         m_db = new Xapian::WritableDatabase(path.toUtf8().constData(), Xapian::DB_CREATE_OR_OPEN);
     } catch (const Xapian::DatabaseCorruptError &err) {
         qCWarning(AKONADI_INDEXER_AGENT_LOG) << "Database Corrupted - What did you do?";
         qCWarning(AKONADI_INDEXER_AGENT_LOG) << err.get_error_string();
-        m_db = 0;
+        m_db = nullptr;
     } catch (const Xapian::Error &e) {
         qCWarning(AKONADI_INDEXER_AGENT_LOG) << QString::fromStdString(e.get_type()) << QString::fromStdString(e.get_description());
-        m_db = 0;
+        m_db = nullptr;
     }
 
     try {
@@ -47,10 +47,10 @@ EmailIndexer::EmailIndexer(const QString &path, const QString &contactDbPath):
     } catch (const Xapian::DatabaseCorruptError &err) {
         qCWarning(AKONADI_INDEXER_AGENT_LOG) << "Database Corrupted - What did you do?";
         qCWarning(AKONADI_INDEXER_AGENT_LOG) << err.get_error_string();
-        m_contactDb = 0;
+        m_contactDb = nullptr;
     } catch (const Xapian::Error &e) {
         qCWarning(AKONADI_INDEXER_AGENT_LOG) << QString::fromStdString(e.get_type()) << QString::fromStdString(e.get_description());
-        m_contactDb = 0;
+        m_contactDb = nullptr;
     }
 }
 
@@ -115,8 +115,8 @@ void EmailIndexer::index(const Akonadi::Item &item)
     delete m_doc;
     delete m_termGen;
 
-    m_doc = 0;
-    m_termGen = 0;
+    m_doc = nullptr;
+    m_termGen = nullptr;
     qCDebug(AKONADI_INDEXER_AGENT_LOG) << "DONE Indexing item" << item.id();
 }
 
@@ -161,7 +161,7 @@ void EmailIndexer::insert(const QByteArray &key, const KMime::Types::Mailbox::Li
     if (!m_contactDb) {
         return;
     }
-    Q_FOREACH (const KMime::Types::Mailbox &mbox, list) {
+    for (const KMime::Types::Mailbox &mbox : list) {
         std::string name(mbox.name().toUtf8().constData());
         m_termGen->index_text_without_positions(name, 1, key.data());
         m_termGen->index_text_without_positions(name, 1);
@@ -242,7 +242,7 @@ void EmailIndexer::process(const KMime::Message::Ptr &msg)
         m_termGen->index_text_without_positions(text);
         m_termGen->index_text_without_positions(text, 1, "BO");
     } else {
-        processPart(msg.data(), 0);
+        processPart(msg.data(), nullptr);
     }
 }
 
@@ -259,7 +259,7 @@ void EmailIndexer::processPart(KMime::Content *content, KMime::Content *mainCont
                 return;
             }
 
-            Q_FOREACH (KMime::Content *c, content->contents()) {
+            for (KMime::Content *c : content->contents()) {
                 processPart(c, mainContent);
             }
         }
@@ -334,7 +334,7 @@ void EmailIndexer::updateFlags(const Akonadi::Item &item,
         return;
     }
 
-    Q_FOREACH (const QByteArray &flag, removed) {
+    for (const QByteArray &flag : removed) {
         if (flag == Akonadi::MessageFlags::Seen) {
             toggleFlag(doc, "BR", "BNR");
         } else if (flag == Akonadi::MessageFlags::Flagged) {
@@ -344,7 +344,7 @@ void EmailIndexer::updateFlags(const Akonadi::Item &item,
         }
     }
 
-    Q_FOREACH (const QByteArray &flag, added) {
+    for (const QByteArray &flag : added) {
         if (flag == Akonadi::MessageFlags::Seen) {
             toggleFlag(doc, "BNR", "BR");
         } else if (flag == Akonadi::MessageFlags::Flagged) {
