@@ -27,10 +27,8 @@
 #include <QString>
 #include <QStringList>
 #include <QSharedPointer>
-#include <QList>
 #include <QUrlQuery>
 #include <QVariant>
-#include <QDebug>
 
 #include <QJsonDocument>
 #include <QJsonObject>
