@@ -42,7 +42,7 @@ public:
     explicit AkonadiSearchSyntaxHighlighter(QTextDocument *doc);
     ~AkonadiSearchSyntaxHighlighter();
 
-    void highlightBlock(const QString &text) Q_DECL_OVERRIDE;
+    void highlightBlock(const QString &text) override;
 
 protected:
     void init();
