@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2014-2015 Montel Laurent <montel@kde.org>
+  Copyright (c) 2014-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -24,7 +24,7 @@ class AkonadiSearchDebugWidgetTest : public QObject
 {
     Q_OBJECT
 public:
-    explicit AkonadiSearchDebugWidgetTest(QObject *parent = Q_NULLPTR);
+    explicit AkonadiSearchDebugWidgetTest(QObject *parent = nullptr);
     ~AkonadiSearchDebugWidgetTest();
 private Q_SLOTS:
     void shouldHaveDefaultValue();
