@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2014-2015 Montel Laurent <montel@kde.org>
+  Copyright (c) 2014-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -50,7 +50,7 @@ private:
     QStringList mArguments;
     QString mAkonadiId;
     QString mPath;
-    QProcess *mProcess;
+    QProcess *mProcess = nullptr;
 };
 }
 }
