@@ -1,6 +1,6 @@
 /*
  * This file is part of the KDE Akonadi Search Project
- * Copyright (C) 2016 Laurent Montel <montel@kde.org>
+ * Copyright (C) 2016-2017 Laurent Montel <montel@kde.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -37,7 +37,7 @@ class AKONADI_SEARCH_PIM_EXPORT IndexedItems : public QObject
 {
     Q_OBJECT
 public:
-    explicit IndexedItems(QObject *parent = Q_NULLPTR);
+    explicit IndexedItems(QObject *parent = nullptr);
     ~IndexedItems();
 
     void setOverrideDbPrefixPath(const QString &path);
