@@ -19,16 +19,15 @@
 
 #include "pimcontactsrunnerconfig.h"
 
-#include <QFormLayout>
 #include <QCheckBox>
-
+#include <QVBoxLayout>
 #include <KLocalizedString>
 #include <KSharedConfig>
 #include <KConfigGroup>
 #include <KPluginFactory>
 
 K_PLUGIN_FACTORY(PIMContactsRunnerConfigFactory,
-                 registerPlugin<PIMContactsRunnerConfig>("kcm_krunner_pimcontacts");)
+                 registerPlugin<PIMContactsRunnerConfig>(QStringLiteral("kcm_krunner_pimcontacts"));)
 
 PIMContactsRunnerConfig::PIMContactsRunnerConfig(QWidget *parent, const QVariantList &args)
     : KCModule(parent, args)
@@ -36,14 +35,19 @@ PIMContactsRunnerConfig::PIMContactsRunnerConfig(QWidget *parent, const QVariant
     QVBoxLayout *vbox = new QVBoxLayout(this);
 
     mQueryCompletionCheckBox = new QCheckBox(i18n("Search in contacts indexed from sent and received emails too"));
-    connect(mQueryCompletionCheckBox, SIGNAL(stateChanged(int)),
-            this, SLOT(changed()));
+    connect(mQueryCompletionCheckBox, &QCheckBox::stateChanged,
+            this, &PIMContactsRunnerConfig::configChanged);
 
     vbox->addWidget(mQueryCompletionCheckBox);
 
     load();
 }
 
+void PIMContactsRunnerConfig::configChanged()
+{
+    Q_EMIT changed();
+}
+
 void PIMContactsRunnerConfig::load()
 {
     KCModule::load();
@@ -81,4 +85,4 @@ void PIMContactsRunnerConfig::defaults()
     Q_EMIT changed(true);
 }
 
-#include "pimcontactsrunnerconfig.moc"
\ No newline at end of file
+#include "pimcontactsrunnerconfig.moc"
