@@ -23,7 +23,6 @@
 
 #include <QDebug>
 #include <QTemporaryDir>
-#include <QTime>
 #include <QUuid>
 #include <QFileInfo>
 #include <QDir>
@@ -40,7 +39,7 @@ int main(int argc, char **argv)
 
     QCommandLineParser parser;
     parser.addPositionalArgument(QStringLiteral("num"), QStringLiteral("The number of terms. Each term is of length 10"));
-    parser.addOption(QCommandLineOption(QStringList() << "p" << "position", QStringLiteral("Add positional information")));
+    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("p") << QStringLiteral("position"), QStringLiteral("Add positional information")));
     parser.addHelpOption();
     parser.process(app);
 
@@ -63,7 +62,7 @@ int main(int argc, char **argv)
     for (int i = 0; i < size; i++) {
         QByteArray term = QUuid::createUuid().toByteArray().mid(1, 10);
 
-        if (parser.isSet("p")) {
+        if (parser.isSet(QLatin1String("p"))) {
             std::string stdString(term.constData(), term.length());
             doc.doc().add_posting(stdString, i);
         } else {
